==> crawl_0.12.2.orig.tar.xz: stone_soup-0.12.2/source/mgen_enum.h <==
#ifndef MGEN_ENUM_H
#define MGEN_ENUM_H

enum band_type
{
    BAND_NO_BAND                = 0,
    BAND_KOBOLDS,
    BAND_ORCS,
    BAND_ORC_WARRIOR,
    BAND_ORC_KNIGHT,
    BAND_KILLER_BEES,
    BAND_FLYING_SKULLS,
    BAND_SLIME_CREATURES,
    BAND_YAKS,
    BAND_UGLY_THINGS,
    BAND_HELL_HOUNDS,
    BAND_JACKALS,
    BAND_HELL_KNIGHTS,
    BAND_ORC_HIGH_PRIEST,
    BAND_GNOLLS,
    BAND_WIGHTS,
#if TAG_MAJOR_VERSION == 34
    BAND_BUMBLEBEES,
#endif
    BAND_CENTAURS,
    BAND_YAKTAURS,
    BAND_INSUBSTANTIAL_WISPS,
    BAND_OGRE_MAGE,
#if TAG_MAJOR_VERSION > 34
    BAND_OGRE_MAGE_EXTERN,
#endif
    BAND_DEATH_YAKS,
    BAND_NECROMANCER,
    BAND_BALRUG,
    BAND_CACODEMON,
    BAND_EXECUTIONER,
    BAND_HELLWING,
    BAND_DEEP_ELF_FIGHTER,
    BAND_DEEP_ELF_KNIGHT,
    BAND_DEEP_ELF_HIGH_PRIEST,
    BAND_KOBOLD_DEMONOLOGIST,
    BAND_NAGAS,
    BAND_WAR_DOGS,
    BAND_GREEN_RATS,
    BAND_ORANGE_RATS,
    BAND_SHEEP,
    BAND_GHOULS,
    BAND_DEEP_TROLLS,
    BAND_HOGS,
    BAND_HELL_HOGS,
    BAND_VAMPIRE_MOSQUITOES,
    BAND_FIRE_BATS,
    BAND_BOGGARTS,
    BAND_BLINK_FROGS,
    BAND_SKELETAL_WARRIORS,
    BAND_DRACONIAN,
    BAND_PANDEMONIUM_LORD,
    BAND_HARPIES,
    BAND_ILSUIW,
    BAND_AZRAEL,
    BAND_DUVESSA,
    BAND_KHUFU,
    BAND_GOLDEN_EYE,
    BAND_PIKEL,
    BAND_MERFOLK_AQUAMANCER,
    BAND_MERFOLK_IMPALER,
    BAND_MERFOLK_JAVELINEER,
    BAND_ALLIGATOR,
    BAND_ELEPHANT,
    BAND_DEEP_DWARF,
    BAND_SHEDU,
    BAND_REDBACK,
    BAND_SPIDER,
    BAND_JUMPING_SPIDER,
    BAND_TARANTELLA,
    BAND_LAMIA,
    BAND_POLYPHEMUS,
    BAND_VAULT_WARDEN,
#if TAG_MAJOR_VERSION == 34
    BAND_OGRE_MAGE_EXTERN,
#endif
    NUM_BANDS                   // always last
};

enum dragon_class_type
{
    DRAGON_LIZARD,
    DRAGON_DRACONIAN,
    DRAGON_DRAGON,
};

enum proximity_type   // proximity to player to create monster
{
    PROX_ANYWHERE,
    PROX_CLOSE_TO_PLAYER,
    PROX_AWAY_FROM_PLAYER,
    PROX_NEAR_STAIRS,
};

enum mgen_flag_type
{
    MG_PERMIT_BANDS = 0x01,
    MG_FORCE_PLACE  = 0x02,
    MG_FORCE_BEH    = 0x04,
    MG_PLAYER_MADE  = 0x08,
    MG_PATROLLING   = 0x10,
    MG_BAND_MINION  = 0x20,
    MG_DONT_COME    = 0x40, // suppress the "comes into view" spam
};

#endif

==> crawl_0.13.1.orig.tar.xz: stone_soup-0.13.1/source/mgen_enum.h <==
#ifndef MGEN_ENUM_H
#define MGEN_ENUM_H

enum band_type
{
    BAND_NO_BAND                = 0,
    BAND_KOBOLDS,
    BAND_ORCS,
    BAND_ORC_WARRIOR,
    BAND_ORC_KNIGHT,
    BAND_KILLER_BEES,
    BAND_FLYING_SKULLS,
    BAND_SLIME_CREATURES,
    BAND_YAKS,
    BAND_UGLY_THINGS,
    BAND_HELL_HOUNDS,
    BAND_JACKALS,
    BAND_HELL_KNIGHTS,
    BAND_ORC_HIGH_PRIEST,
    BAND_GNOLLS,
    BAND_WIGHTS,
#if TAG_MAJOR_VERSION == 34
    BAND_BUMBLEBEES,
#endif
    BAND_CENTAURS,
    BAND_YAKTAURS,
    BAND_INSUBSTANTIAL_WISPS,
    BAND_OGRE_MAGE,
#if TAG_MAJOR_VERSION > 34
    BAND_OGRE_MAGE_EXTERN,
#endif
    BAND_DEATH_YAKS,
    BAND_NECROMANCER,
    BAND_BALRUG,
    BAND_CACODEMON,
    BAND_EXECUTIONER,
    BAND_HELLWING,
    BAND_DEEP_ELF_FIGHTER,
    BAND_DEEP_ELF_KNIGHT,
    BAND_DEEP_ELF_HIGH_PRIEST,
    BAND_KOBOLD_DEMONOLOGIST,
    BAND_NAGAS,
    BAND_WOLVES,
    BAND_GREEN_RATS,
    BAND_ORANGE_RATS,
    BAND_SHEEP,
    BAND_GHOULS,
    BAND_DEEP_TROLLS,
    BAND_HOGS,
    BAND_HELL_HOGS,
    BAND_VAMPIRE_MOSQUITOES,
    BAND_FIRE_BATS,
    BAND_BOGGARTS,
    BAND_BLINK_FROGS,
    BAND_SKELETAL_WARRIORS,
    BAND_DRACONIAN,
    BAND_PANDEMONIUM_LORD,
    BAND_HARPIES,
    BAND_ILSUIW,
    BAND_AZRAEL,
    BAND_DUVESSA,
    BAND_KHUFU,
    BAND_GOLDEN_EYE,
    BAND_PIKEL,
    BAND_MERFOLK_AQUAMANCER,
    BAND_MERFOLK_IMPALER,
    BAND_MERFOLK_JAVELINEER,
    BAND_ALLIGATOR,
    BAND_ELEPHANT,
#if TAG_MAJOR_VERSION == 34
    BAND_DEEP_DWARF,
#endif
    BAND_SHEDU,
    BAND_REDBACK,
    BAND_SPIDER,
    BAND_JUMPING_SPIDER,
    BAND_TARANTELLA,
#if TAG_MAJOR_VERSION == 34
    BAND_LAMIA,
#endif
    BAND_POLYPHEMUS,
    BAND_VAULT_WARDEN,
#if TAG_MAJOR_VERSION == 34
    BAND_OGRE_MAGE_EXTERN,
#endif
    BAND_DEATH_KNIGHT,
    BAND_JIANGSHI,
    BAND_FAUNS,
    BAND_PAN,
    BAND_TENGU,
    BAND_SOJOBO,
    BAND_SPRIGGANS,
    BAND_SPRIGGAN_ELITES,
    BAND_ENCHANTRESS,
    BAND_AIR_ELEMENTALS,
    BAND_SPRIGGAN_DRUID,
    BAND_SPRIGGAN_RIDERS,
    BAND_SPIRIT_WOLVES,
    BAND_PHANTASMAL_WARRIORS,
    BAND_WATER_ELEMENTALS,
    NUM_BANDS                   // always last
};

enum dragon_class_type
{
    DRAGON_LIZARD,
    DRAGON_DRACONIAN,
    DRAGON_DRAGON,
};

enum proximity_type   // proximity to player to create monster
{
    PROX_ANYWHERE,
    PROX_CLOSE_TO_PLAYER,
    PROX_AWAY_FROM_PLAYER,
    PROX_NEAR_STAIRS,
};

enum mgen_flag_type
{
    MG_PERMIT_BANDS = 0x01,
    MG_FORCE_PLACE  = 0x02,
    MG_FORCE_BEH    = 0x04,
    MG_PLAYER_MADE  = 0x08,
    MG_PATROLLING   = 0x10,
    MG_BAND_MINION  = 0x20,
    MG_DONT_COME    = 0x40, // suppress the "comes into view" spam
};

#endif
